about summary refs log tree commit diff
diff options
context:
space:
mode:
authorZalathar <Zalathar@users.noreply.github.com>2023-09-14 13:01:54 +1000
committerZalathar <Zalathar@users.noreply.github.com>2023-09-14 13:01:54 +1000
commitc397ca0677e31297f2be8a0391f3c7389618d05b (patch)
tree2bfc41be937a65b21ad4936fab31eb311eb49c8c
parentc728bf3963433062b91bd84ffcb37d15416b800e (diff)
downloadrust-c397ca0677e31297f2be8a0391f3c7389618d05b.tar.gz
rust-c397ca0677e31297f2be8a0391f3c7389618d05b.zip
Fix the error message for `#![feature(no_coverage)]`
-rw-r--r--compiler/rustc_feature/src/removed.rs4
-rw-r--r--tests/ui/feature-gates/feature-gate-coverage-attribute.stderr2
2 files changed, 3 insertions, 3 deletions
diff --git a/tests/ui/feature-gates/feature-gate-coverage-attribute.stderr b/tests/ui/feature-gates/feature-gate-coverage-attribute.stderr
index 3912b9834fe..0131a19a39d 100644
--- a/tests/ui/feature-gates/feature-gate-coverage-attribute.stderr
+++ b/tests/ui/feature-gates/feature-gate-coverage-attribute.stderr
@@ -4,7 +4,7 @@ error[E0557]: feature has been removed
 LL | #![feature(no_coverage)]
    |            ^^^^^^^^^^^ feature has been removed
    |
-   = note: renamed to `coverage`
+   = note: renamed to `coverage_attribute`
 
 error[E0658]: the `#[coverage]` attribute is an experimental feature
   --> $DIR/feature-gate-coverage-attribute.rs:10:1
diff --git a/compiler/rustc_feature/src/removed.rs b/compiler/rustc_feature/src/removed.rs
index c70e8e3e6b1..da18cb2a239 100644
--- a/compiler/rustc_feature/src/removed.rs
+++ b/compiler/rustc_feature/src/removed.rs
@@ -137,8 +137,8 @@ declare_features! (
     /// Allows use of unary negate on unsigned integers, e.g., -e for e: u8
     (removed, negate_unsigned, "1.0.0", Some(29645), None, None),
     /// Allows `#[no_coverage]` on functions.
-    /// The feature was renamed to `coverage` and the attribute to `#[coverage(on|off)]`
-    (removed, no_coverage, "CURRENT_RUSTC_VERSION", Some(84605), None, Some("renamed to `coverage`")),
+    /// The feature was renamed to `coverage_attribute` and the attribute to `#[coverage(on|off)]`
+    (removed, no_coverage, "CURRENT_RUSTC_VERSION", Some(84605), None, Some("renamed to `coverage_attribute`")),
     /// Allows `#[no_debug]`.
     (removed, no_debug, "1.43.0", Some(29721), None, Some("removed due to lack of demand")),
     /// Allows using `#[on_unimplemented(..)]` on traits.